@@ -20,11 +20,13 @@ def extractor(fileobj, keywords, comment_tags, options):
     tree = html.parse(fileobj)
     for el in tree.xpath('//*[@data-trans]'):
         for message_id in trans_message_ids(el):
-            yield (el.sourceline, None, message_id, [])
+            funcname, message_id = pluralize(message_id)
+            yield (el.sourceline, funcname, message_id, [])
     for el in tree.xpath('//*[@data-tvar]'):
         message_id  = tvar_message_id(el)
         if message_id is not None:
-            yield (el.sourceline, None, message_id, [])
+            funcname, message_id = pluralize(message_id)
+            yield (el.sourceline, funcname, message_id, [])
 
 def html_extractor(fileobj, keywords, comment_tags, options):
     """Extract messages from HTML with embedded obvt text/template script tags.
@@ -36,7 +38,20 @@ def html_extractor(fileobj, keywords, comment_tags, options):
             StringIO(el.text), keywords, comment_tags,
             options):
             yield el_sourceline + sourceline - 1, d, message_id, l
-    
+
+def pluralize(message_id):
+    """A hack to make the system output plural message ids when needed.
+
+    When a non-string message id is returned we want plurals. We can
+    enforce this by using the funcname argument we yield.
+    """
+    parts = message_id.split('||')
+    if len(parts) == 1:
+        return None, message_id
+    if len(parts) > 2:
+        raise ExtractionError(None, "too many || in plural")
+    return 'ngettext', tuple(parts)
+
 class TransInfo(object):
     def __init__(self, content_id, message_id):
         self.content_id = content_id
@@ -71,9 +86,9 @@ def trans_message_ids(el):
         if transinfo.message_id is not None:
             yield transinfo.message_id
         elif transinfo.content_id == '.':
-            yield text_message_id(el)
+            yield text_message_id(el).strip()
         else:
-            yield el.get(transinfo.content_id)
+            yield el.get(transinfo.content_id.strip())
 
 def parse_tvar(el, tvar):
     tvar = tvar.strip()
@@ -105,7 +120,7 @@ def parse_view(el, view):
 def tvar_message_id(el):
     # don't want to extract tvar if there's no actual content to translate
     # (no text, or single variable by itself)
-    message_id = text_message_id(el)
+    message_id = text_message_id(el).strip()
     tokens = tokenize(message_id)
     if len(tokens) == 0:
         return None
