@@ -11,7 +11,7 @@ def test_text():
         lineno, funcname, message, comments = r[0]
         assert lineno == 1
         assert message == 'Hello world!'
-        
+        assert funcname is None
 
 def test_text_explicit():
     with open(datafile('test2.obvt')) as f:
@@ -145,6 +145,42 @@ def test_variable_with_formatter():
         assert message == 'Hello {who}!'
     
 
+def test_plural():
+    with open(datafile('test17.obvt')) as f:
+        r = list(extractor(f, [], [], []))
+        assert len(r) == 1
+        lineno, funcname, message, comments = r[0]
+        assert lineno == 1
+        assert message == ('{count} cow', '{count} cows')
+        assert funcname == 'ngettext'
+        
+def test_plural_explicit():
+    with open(datafile('test18.obvt')) as f:
+        r = list(extractor(f, [], [], []))
+        assert len(r) == 1
+        lineno, funcname, message, comments = r[0]
+        assert lineno == 1
+        assert message == ('{count} cow', '{count} cows')
+
+def test_plural_attribute():
+    with open(datafile('test19.obvt')) as f:
+        r = list(extractor(f, [], [], []))
+        assert len(r) == 1
+        lineno, funcname, message, comments = r[0]
+        assert lineno == 1
+        assert message == ('{count} cow', '{count} cows')
+
+def test_plural_tvar():
+    with open(datafile('test20.obvt')) as f:
+        r = list(extractor(f, [], [], []))
+        assert len(r) == 2
+        lineno, funcname, message, comments = r[0]
+        assert lineno == 1
+        assert message == "I count {something}"
+        lineno, funcname, message, comments = r[1]
+        assert lineno == 1
+        assert message == ('{count} cow', '{count} cows')
+
 def test_html_extractor():
     with open(datafile('test1.html')) as f:
         r = list(html_extractor(f, [], [], []))
@@ -160,3 +196,20 @@ def test_html_extractor_multi_line():
         lineno, funcname, message, comments = r[0]
         assert lineno == 5
         assert message == 'Hello {who}!'
+
+def test_whitespace():
+    with open(datafile('test21.obvt')) as f:
+        r = list(extractor(f, [], [], []))
+        assert len(r) == 1
+        lineno, funcname, message, comments = r[0]
+        assert message == "This has whitespace."
+                 
+
+def test_whitespace():
+    with open(datafile('test22.obvt')) as f:
+        r = list(extractor(f, [], [], []))
+        assert len(r) == 2
+        lineno, funcname, message, comments = r[0]
+        assert message == "{something} is up."
+        lineno, funcname, message, comments = r[1]
+        assert message == "This has whitespace."
